@@ -28,6 +28,9 @@ def process(
     bibdoc=False,
     bd_ssh_host=None,
     timestamp=0,
+    cert=None,
+    invcookie=None,
+    skipssl=False
 ):
     # Save timestamp
     timestamp = int(time.time())
@@ -45,6 +48,7 @@ def process(
         "bibdoc": bibdoc,
         "bd_ssh_host": bd_ssh_host,
         "timestamp": timestamp,
+        "cert": cert
     }
 
     try:
@@ -102,10 +106,13 @@ def process(
     try:
         # Initialize the pipeline
         if source == "cds":
-            pipeline = invenio_v1.InvenioV1Pipeline("https://cds.cern.ch/record/")
+            pipeline = invenio_v1.InvenioV1Pipeline(
+                "https://cds.cern.ch/record/", cert_path=cert, recid=recid, 
+                invcookie=invcookie, skipssl=skipssl)
         elif source == "ilcdoc":
             pipeline = invenio_v1.InvenioV1Pipeline(
-                "http://ilcdoc.linearcollider.org/record/"
+                "http://ilcdoc.linearcollider.org/record/", cert_path=cert, 
+                recid=recid, invcookie=invcookie, skipssl=skipssl
             )
         elif source == "cod":
             pipeline = opendata.OpenDataPipeline("http://opendata.cern.ch")
@@ -173,7 +180,7 @@ def process(
 
         if dry_run is True:
             # Create fetch.txt
-            pipeline.create_fetch_txt(files, f"{base_path}/fetch.txt")
+            pipeline.create_fetch_txt(files, source, f"{base_path}/fetch.txt")
         else:
 
             if source == "local":
@@ -183,7 +190,7 @@ def process(
 
             else:
                 # Download files
-                files = pipeline.download_files(files, f"{base_path}/data/content")
+                files = pipeline.download_files(files, base_path)
 
         # To allow consistency and hashing of the attached log,
         # no events after this point will be logged to the file
@@ -242,7 +249,7 @@ def process(
         if log.hasHandlers():
             log.handlers.clear()
 
-        return {"status": 0, "errormsg": None}
+        return {"status": 0, "errormsg": None, "foldername": name}
 
     # Folder exists, gracefully stop
     except FileExistsError as e:
